@@ -136,23 +136,32 @@ def initialize_options(arguments: list[str] | None = None) -> BaseFileLock | Non
     options.warn_list = [normalize_tag(tag) for tag in options.warn_list]
 
     options.configured = True
-    options.cache_dir = get_cache_dir(pathlib.Path(options.project_dir))
+    if not (
+        options.version
+        or options.list_profiles
+        or options.list_rules
+        or options.list_tags
+    ):
+        options.cache_dir = get_cache_dir(pathlib.Path(options.project_dir))
+
+    options.project_dir = Path(options.project_dir).resolve().as_posix()
 
     # add a lock file so we do not have two instances running inside at the same time
     if options.cache_dir:
         options.cache_dir.mkdir(parents=True, exist_ok=True)
 
-    if not options.offline:  # pragma: no cover
-        cache_dir_lock = FileLock(
-            f"{options.cache_dir}/.lock",
-        )
-        try:
-            cache_dir_lock.acquire(timeout=180)
-        except Timeout:  # pragma: no cover
-            _logger.error(  # noqa: TRY400
-                "Timeout waiting for another instance of ansible-lint to release the lock.",
+        # lock file can only be used if cache_dir is set and writable
+        if not options.offline:  # pragma: no cover
+            cache_dir_lock = FileLock(
+                f"{options.cache_dir}/.lock",
             )
-            sys.exit(RC.LOCK_TIMEOUT)
+            try:
+                cache_dir_lock.acquire(timeout=180)
+            except Timeout:  # pragma: no cover
+                _logger.error(  # noqa: TRY400
+                    "Timeout waiting for another instance of ansible-lint to release the lock.",
+                )
+                sys.exit(RC.LOCK_TIMEOUT)
 
     # Avoid extra output noise from Ansible about using devel versions
     if "ANSIBLE_DEVEL_WARNING" not in os.environ:  # pragma: no branch
@@ -369,9 +378,9 @@ def main(argv: list[str] | None = None) -> int:
         cached=True,
     )  # to be sure we use the offline value from settings
     rules = RulesCollection(
-        options.rulesdirs,
-        profile_name=options.profile,
         app=app,
+        rulesdirs=options.rulesdirs,
+        profile_name=options.profile,
         options=options,
     )
 
